Tutorials
=========

These tutorials are a good place to start if you are new to pystencils.
All tutorials and demos listed here are based on Jupyter notebooks that you can find in the pystencils repository.
It is a good idea to download them and run them directly to be able to play around with the code.

.. toctree::
   :maxdepth: 1

   /notebooks/01_tutorial_getting_started.ipynb
   /notebooks/02_tutorial_basic_kernels.ipynb
   /notebooks/03_tutorial_datahandling.ipynb
   /notebooks/04_tutorial_advection_diffusion.ipynb
   /notebooks/05_tutorial_phasefield_spinodal_decomposition.ipynb
   /notebooks/06_tutorial_phasefield_dentritic_growth.ipynb
   /notebooks/demo_assignment_collection.ipynb
   /notebooks/demo_plotting_and_animation.ipynb
   /notebooks/demo_derivatives.ipynb
   /notebooks/demo_benchmark.ipynb
   /notebooks/demo_wave_equation.ipynb
